@@ -12,7 +12,7 @@
 ##'
 ##' @return a tibble with all individual tibble's appended
 ##'
-##' @importFrom dplyr select bind_rows "%>%"
+##' @importFrom dplyr select bind_rows "%>%" everything
 ##' @importFrom sf st_crs st_coordinates st_transform st_geometry st_as_sf st_set_crs
 ##' @importFrom tibble as_tibble
 ##'
@@ -62,7 +62,7 @@ grab <- function(x, what = "fitted", as_sf = TRUE) {
                as.data.frame(.)
              names(xy) <- c("x", "y")
              ll <- x %>%
-               st_transform(4326) %>%
+               st_transform("+proj=longlat +datum=WGS84 +no_defs") %>%
                st_coordinates(.) %>%
                as.data.frame(.)
              names(ll) <- c("lon", "lat")
@@ -81,7 +81,7 @@ grab <- function(x, what = "fitted", as_sf = TRUE) {
                ))
              out <- lapply(1:length(out_lst), function(i) {
                st_as_sf(out_lst[[i]], coords = c("lon", "lat")) %>%
-                 st_set_crs(4326) %>%
+                 st_set_crs("+proj=longlat +datum=WGS84 +no_defs") %>%
                  st_transform(., prj[[i]])
              }) %>%
                bind_rows(.)
@@ -89,8 +89,14 @@ grab <- function(x, what = "fitted", as_sf = TRUE) {
              if (what != "data") {
                out <- switch(
                  x$ssm[[1]]$pm,
-                 rw = out %>% select(id, date, x.se, y.se, geometry),
-                 crw = out %>% select(id, date, u, v, u.se, v.se, x.se, y.se, geometry)
+                 rw = {
+                   out %>% select(id, date, x.se, y.se, geometry)
+                   },
+                 crw = {
+                   ## use everything() to deal w fit objects from <= 0.6-9, which don't contain s, s.se
+                   out %>% select(id, date, u, v, u.se, v.se, x.se, 
+                                      y.se, everything())
+                 }
                )
                
              } else {
@@ -114,7 +120,8 @@ grab <- function(x, what = "fitted", as_sf = TRUE) {
                out <- switch(
                  x$ssm[[1]]$pm,
                  rw = out %>% select(id, date, lon, lat, x, y, x.se, y.se),
-                 crw = out  %>% select(id, date, lon, lat, x, y, x.se, y.se, u, v, u.se, v.se)
+                 crw = out  %>% select(id, date, lon, lat, x, y, x.se, y.se, 
+                                       u, v, u.se, v.se, everything())
                ) %>% as_tibble()
              } else {
                out <- out %>%
